@@ -1,13 +1,12 @@
 import logging
-from enum import Enum, unique
 from typing import Any, Dict, List, Optional, Tuple
 
 import sqlalchemy as sa
 from datayoga_core import utils, write_utils
 from datayoga_core.block import Block as DyBlock
+from datayoga_core.blocks.relational import utils as relational_utils
 from datayoga_core.context import Context
 from datayoga_core.result import Result
-from sqlalchemy import Table
 from sqlalchemy.engine import CursorResult
 from sqlalchemy.exc import OperationalError
 from sqlalchemy.sql.expression import ColumnCollection
@@ -15,34 +14,14 @@ from sqlalchemy.sql.expression import ColumnCollection
 logger = logging.getLogger("dy")
 
 
-@unique
-class DbType(Enum):
-    MSSQL = "mssql"
-    MYSQL = "mysql"
-    PSQL = "postgresql"
-
-    @classmethod
-    def has_value(cls, value: str) -> bool:
-        return value in cls._value2member_map_
-
-
-DEFAULT_DRIVERS = {
-    DbType.MYSQL.value: "mysql+pymysql",
-    DbType.MSSQL.value: "mssql+pymssql",
-    DbType.PSQL.value: "postgresql"
-}
-
 class Block(DyBlock):
 
     def init(self, context: Optional[Context] = None):
         logger.debug(f"Initializing {self.get_block_name()}")
 
-        connection = utils.get_connection_details(self.properties.get("connection"), context)
-
-        self.db_type = connection.get("type").lower()
-        if not DbType.has_value(self.db_type):
-            raise ValueError(f"{self.db_type} is not supported yet")
+        engine, db_type = relational_utils.get_engine(self.properties.get("connection"), context)
 
+        self.db_type = db_type
         self.schema = self.properties.get("schema")
         self.table = self.properties.get("table")
         self.opcode_field = self.properties.get("opcode_field")
@@ -50,20 +29,15 @@ class Block(DyBlock):
         self.keys = self.properties.get("keys")
         self.mapping = self.properties.get("mapping")
 
-        engine = sa.create_engine(
-            sa.engine.URL.create(
-                drivername=connection.get("driver", DEFAULT_DRIVERS.get(self.db_type)),
-                host=connection.get("host"),
-                port=connection.get("port"),
-                username=connection.get("user"),
-                password=connection.get("password"),
-                database=connection.get("database")),
-            echo=connection.get("debug", False), connect_args=connection.get("connect_args", {}))
         self.tbl = sa.Table(self.table, sa.MetaData(schema=self.schema), autoload_with=engine)
 
         logger.debug(f"Connecting to {self.db_type}")
         self.connection = engine.connect()
 
+        if self.db_type == relational_utils.DbType.MSSQL:
+            # MERGE statement requires this
+            self.connection = self.connection.execution_options(autocommit=True)
+
         if self.opcode_field:
             self.business_key_columns = [column["column"] for column in write_utils.get_column_mapping(self.keys)]
             self.mapping_columns = [column["column"] for column in write_utils.get_column_mapping(self.mapping)]
@@ -97,7 +71,7 @@ class Block(DyBlock):
 
     def generate_upsert_stmt(self) -> Any:
         """Generates an UPSERT statement based on the DB type"""
-        if self.db_type == DbType.PSQL.value:
+        if self.db_type == relational_utils.DbType.PSQL.value:
             from sqlalchemy.dialects.postgresql import insert
 
             insert_stmt = insert(self.tbl).values({col: "?" for col in self.columns})
@@ -105,14 +79,14 @@ class Block(DyBlock):
                 index_elements=self.business_key_columns,
                 set_={col: getattr(insert_stmt.excluded, col) for col in self.columns})
 
-        if self.db_type == DbType.MYSQL.value:
+        if self.db_type == relational_utils.DbType.MYSQL:
             from sqlalchemy.dialects.mysql import insert
 
             insert_stmt = insert(self.tbl).values({col: "?" for col in self.columns})
             return insert_stmt.on_duplicate_key_update(ColumnCollection(
                 columns=[(x.name, x) for x in [insert_stmt.inserted[column] for column in self.columns]]))
 
-        if self.db_type == DbType.MSSQL.value:
+        if self.db_type == relational_utils.DbType.MSSQL:
             return sa.sql.text("""
                     MERGE %s AS target
                     USING (VALUES (%s)) AS source (%s) ON (%s)
