@@ -1,5 +1,5 @@
 import logging
-from typing import Any, Dict, List, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 from datayoga_core import utils
 from datayoga_core.block import Block as DyBlock
@@ -10,7 +10,7 @@ logger = logging.getLogger("dy")
 
 
 class Block(DyBlock):
-    def init(self, context: Context = None):
+    def init(self, context: Optional[Context] = None):
         logger.debug(f"Initializing {self.get_block_name()}")
         self.properties = utils.format_block_properties(self.properties)
 
